import os


def 文件夹_创建(path: str) -> bool:
    """
    :param path:  只能传入文件夹, 不能传入具体文件路径
    :return: True:创建成功, False:创建失败
    """
    # 检查是否是具体文件路径
    folder = os.path.exists(path)

    if not folder:  # 判断是否存在文件夹如果不存在则创建为文件夹
        os.makedirs(path)  # makedirs 创建文件时如果路径不存在会创建这个路径
        print(f"---  创建文件: {path}...  ---")
        return True
    else:
        print("---  创建文件: 文件已存在!  ---")
        return False



"""
# File       : zip文件读取.py
# Time       ：2023/9/25 15:00
# Author     ：xuewei zhang
# Email      ：jingmu_predict@qq.com
# version    ：python 3.8
# Description：
"""
import zipfile

from typing import Tuple


class 读取ZIP文件:
    def __init__(self, zip_file: str):
        self.__opened_zip = zipfile.ZipFile(zip_file, 'r')

    def 所有文件名(self, 文件后缀: str = None):
        # 列出ZIP中的所有文件
        _file_list = self.__opened_zip.namelist()
        # 找到所有以suffix结尾的文件
        if 文件后缀 is not None:
            _csv_filename = [filename for filename in _file_list if filename.endswith(文件后缀)]
        else:
            _csv_filename = _file_list
        return _csv_filename

    def 打开文件(self, zip内的文件名: str):
        return self.__opened_zip.open(zip内的文件名)


if __name__ == '__main__':
    import pandas as pd

    file = "/Volumes/AI_1505056/量化交易/币安_K线数据/BTCUSDT-1m-2019-09.zip"
    f = 读取ZIP文件(file)
    n = f.所有文件名(".csv")
    print(n)

    # read csv from bytes
    p = pd.read_csv(f.打开文件(n[0]))
    print(p.head())



"""
# File       : 后端服务_Excel数据_流传输.py
# Time       ：2023/9/14 08:26
# Author     ：xuewei zhang
# Email      ：jingmu_predict@qq.com
# version    ：python 3.8
# Description：
"""
import xlwt
from io import BytesIO
from fastapi.responses import StreamingResponse


def export_exl(header, data, data_col, file_name='download.xlsx', need_order=False):
    """
    以流的形式导出到excel
    :param header: ['列名1', '列名2']
    :param data: [{'a': 1, 'b': 2}]			数据集，与header、data_col对应
    :param data_col: ['与列名对应的字段1', '与列名对应的字段2']
    :param file_name:
    :param need_order:
    :return:
    """

    def set_style():
        """
        设置样式
        :return:
        """
        # 居中设置
        alignment = xlwt.Alignment()
        alignment.horz = xlwt.Alignment.HORZ_CENTER
        alignment.vert = xlwt.Alignment.VERT_CENTER

        # 设置表头字体样式
        head_style = xlwt.XFStyle()
        font = xlwt.Font()
        font.name = 'Times New Roman'  # 字体
        font.bold = True  # 字体加粗
        font.height = int(15 * 10 * 2 * 1.3)
        head_style.font = font  # 设置字体
        head_style.alignment = alignment  # Add Alignment to Style

        # 设置表中内容样式
        cont_style = xlwt.XFStyle()
        font = xlwt.Font()
        font.name = 'Times New Roman'  # 字体
        font.bold = False  # 字体加粗
        font.height = 15 * 10 * 2
        cont_style.font = font  # 设置字体
        cont_style.alignment = alignment  # Add Alignment to Style

        # 设置单元格边界
        borders = xlwt.Borders()
        borders.left = xlwt.Borders.THIN
        borders.right = xlwt.Borders.THIN
        borders.top = xlwt.Borders.THIN
        borders.bottom = xlwt.Borders.THIN
        head_style.borders = borders
        cont_style.borders = borders
        return head_style, cont_style

    def get_sheet(_book, _index):
        """
        创建sheet页
        :param _book:
        :param _index:
        :return:
        """
        _name = "sheet_{}".format(str(_index))
        _sheet = _book.add_sheet(_name)
        return _sheet

    def write_head(_head, _sheet, _head_style):
        """
        写入表头
        :param _head:
        :param _sheet:
        :param _head_style:
        :return:
        """
        for head in range(len(header)):
            context = str(header[head])
            need_width = (1 + len(context)) * 256
            if need_width < 4500:
                need_width = 4500
            table_sheet.col(head).width = need_width
            table_sheet.write(0, head, context, style=_head_style)

    # 是否插入序号
    if need_order:
        header.insert(0, '序号')

    sheet_index = 1
    book = xlwt.Workbook(encoding='utf-8')  # 创建 Excel 文件
    table_sheet = get_sheet(book, sheet_index)  # 添加sheet表
    h_style, c_style = set_style()
    write_head(header, table_sheet, h_style)

    # 插入数据
    row = 1
    for item in data:
        if need_order:
            table_sheet.write(row, 0, row, style=c_style)  # 写入序号
            for col in range(len(header[1:])):
                table_sheet.write(
                    row, col + 1, str(item.get(data_col[col], '-') if item.get(data_col[col]) else '-'), style=c_style)
        else:
            for col in range(len(header)):
                table_sheet.write(
                    row, col, str(item.get(data_col[col], '-') if item.get(data_col[col]) else '-'), style=c_style)
        row += 1

        if row > 50000:  # 单表数量超过 65535 条 添加新的表
            row = 1
            sheet_index += 1
            table_sheet = get_sheet(book, sheet_index)  # 添加sheet表
            write_head(header, table_sheet, h_style)

    sio = BytesIO()  # 返回文件流到浏览端下载，浏览端必须以form提交方式方能下载成功！
    book.save(sio)  # 这点很重要，传给save函数的不是保存文件名，而是一个StringIO流
    sio.seek(0)  # 保存流
    # 组装header
    headers = {"content-type": "application/vnd.ms-excel",
               "content-disposition": f'attachment;filename={file_name}'}
    # 以流的形式返回浏览器
    return StreamingResponse(sio, media_type='xls/xlsx', headers=headers)



"""
# File       : setup.py
# Time       ：2023/9/14 15:29
# Author     ：xuewei zhang
# Email      ：jingmu_predict@qq.com
# version    ：python 3.8
# Description：
"""
from setuptools import setup, find_packages

setup(
    name="file_tools_zxw",
    version="1.2",
    packages=find_packages(),
    install_requires=[
        'xlwt',
        'fastapi',
        'psutil'
        # 依赖的其他包，例如：'requests>=2.0.0'
    ],
    author="XueWei Zhang",
    author_email="tonson_predict@qq.com",
    description="常用的文件操作的中文工具包,如文件查找,创建文件夹, 文件夹查找,ZIP文件读取等.",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/mypackage",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



import os


def 文件_占用空间_获取_MB(files_path: list[str]) -> float:
    total_size = 0.0

    for item in files_path:
        file_size_bytes = os.stat(item)
        file_size_mb = file_size_bytes.st_size / (1024 * 1024)
        total_size += file_size_mb

    return total_size


if __name__ == '__main__':
    files = ["/Users/zhangxuewei/Google 云端硬盘/软件开发/润心/软件测试-性能测试/配套软件/禅道.15.4.win64.exe",
             "/Users/zhangxuewei/Google 云端硬盘/软件开发/润心/软件测试-性能测试/配套软件/禅道.15.4.win64.exe"]
    print(文件_占用空间_获取_MB(files))



import os
from typing import List, Tuple


def 文件_扫描_fileScan(filepath: str, suffix: str = "") -> List[Tuple[str, str]]:
    """
    扫描文件夹下所有符合条件的文件
    :param filepath:扫描路径
    :param suffix:过滤后缀, 默认值为不进行后缀过滤
    :return:[(文件路径,文件名),...]
    """
    # 参数检查
    if filepath[-1] == "\\" or filepath[-1] == "/":
        raise AttributeError("parameter of filepath can not end with '\\' or '/'")

    # 执行逻辑
    fileList = []
    print("开始扫描【{0}】".format(filepath))
    if not os.path.isdir(filepath):
        print("【{0}】不是目录".format(filepath))
        exit(-1)
    for filename in os.listdir(filepath):
        if os.path.isdir(filepath + "/" + filename):
            fileList.extend(文件_扫描_fileScan(filepath + "/" + filename, suffix))
        else:
            if filename.endswith(suffix):
                fileList.append((filepath, filename))
    return fileList


def 文件夹_扫描_dirScan(filepath: str) -> list[str]:
    """
    扫描指定文件夹下所有文件夹(去重)
    :return:[文件路径,...]
    """
    dirs = 文件_扫描_fileScan(filepath=filepath, suffix="")
    dirs_files = [item[0] for item in dirs]
    #
    return list(set(dirs_files))


if __name__ == '__main__':
    path = "/Users/zhangxuewei/Documents/禅道"
    fileLists = 文件_扫描_fileScan(path, "")

    for item in fileLists:
        print(item)

    # files = 文件夹_扫描_dirScan(path)
    # print(files)



import os


def get项目根目录(projectName: str = "pyAutoWeigh"):
    """
    :param projectName:
    :return: /Users/zhangxuewei/Documents/GitHub/pyAutoWeigh/
    """
    # 获取当前文件的目录
    cur_path = os.path.abspath(os.path.dirname(__file__))
    print(cur_path)
    # 获取根目录
    root_path = cur_path[:cur_path.rindex(f"{projectName}") + len(f"{projectName}")] + "/"
    print(f"proj = {root_path}")
    return root_path


if __name__ == '__main__':
    get项目根目录(projectName="pyAutoWeigh")
